package com.zy.bms.common.aspect;

import com.zy.bms.common.ServerResponse;
import com.zy.bms.utils.DateTimeUtil;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.stereotype.Component;

import java.util.Arrays;

/**
 * 打印日志切面
 *
 * @author yang xiao kun
 * create on 2021/2/25
 */
@Slf4j
@Aspect
@Component
public class LogAspect {

    /**
     * 方法切入点（输出方法执行概要日志）
     * execution(* com.zy.bms.service..*.*(..)) ||
     */
    @Around(value = "execution(* com.zy.bms.controller..*.*(..))")
    public Object around(ProceedingJoinPoint joinPoint) {
        try {
            return joinPoint.proceed();
        } catch (Throwable throwable) {
            log.error(buildMsg(joinPoint), throwable);
        }
        return ServerResponse.error();
    }

    private String buildMsg(ProceedingJoinPoint joinPoint) {
        return "全局异常拦截 -- " + DateTimeUtil.now(DateTimeUtil.Pattern_YMDHMS)
                + ": Class:" + joinPoint.getSignature().getDeclaringTypeName()
                + " Method:" + joinPoint.getSignature().getName()
                + " Args:" + Arrays.toString(joinPoint.getArgs());
    }
}
