package com.zy.bms.controller;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.zy.bms.common.ServerResponse;
import com.zy.bms.manager.SessionManager;
import com.zy.bms.entity.Admin;
import com.zy.bms.pojo.io.AdminIO;
import com.zy.bms.service.IAdminService;
import com.zy.bms.utils.MD5Util;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * 管理员表 前端控制器
 *
 * @author yangxiaokun
 * @since 2021-06-03
 */
@RestController
@RequestMapping("/bms/api/operate/admin")
public class AdminController extends BaseController {
    @Resource
    private IAdminService adminService;
    @Resource
    private SessionManager sessionManager;

    /**
     * 登录
     */
    @PostMapping("login.do")
    public ServerResponse login(String username, String password) {
        Admin admin = adminService.getByUsername(username);
        if (admin == null) return ServerResponse.warning("用户不存在");
        //MD5密码
        password = MD5Util.encode(password);
        if (!admin.getPassword().equals(password)) return ServerResponse.warning("密码错误");
        // 返回 token 和 昵称
        Map<String, String> result = new HashMap<>();
        result.put("token", sessionManager.generateToken(admin));
        result.put("nickname", admin.getNickname());
        return ServerResponse.success(result);
    }

    @GetMapping("logout.do")
    public ServerResponse logout() {
        sessionManager.removeToken(token());
        return ServerResponse.success();
    }

    /**
     * 分页查询管理员列表
     */
    @PostMapping("listPage.do")
    public ServerResponse listPage(AdminIO io) {
        return ServerResponse.success(adminService.listPage(io));
    }

    /**
     * 添加用户
     */
    @PostMapping("save.do")
    public ServerResponse save(Admin admin) {
        Admin current = sessionManager.getUser(token());
        if (current == null || current.getRoleId() != 1)
            return ServerResponse.warning("无权限");
        adminService.save(admin);
        return ServerResponse.success();
    }

    /**
     * 禁用
     */
    @PostMapping("forbidden.do")
    public ServerResponse forbidden(Integer id) {
        adminService.update(new UpdateWrapper<Admin>().set("status", 0).eq("id", id));
        return ServerResponse.success();
    }

    /**
     * 启用
     */
    @PostMapping("permit.do")
    public ServerResponse permit(Integer id) {
        adminService.update(new UpdateWrapper<Admin>().set("status", 1).eq("id", id));
        return ServerResponse.success();
    }

    /**
     * 查询用户名是否重复
     */
    @PostMapping("checkRepeat.do")
    public ServerResponse checkRepeat(String username) {
        return ServerResponse.success(adminService.checkRepeat(username));
    }

    /**
     * token 验证
     */
    @GetMapping("verify.do")
    public ServerResponse verify() {
        return ServerResponse.success();
    }
}
