package com.zy.bms.controller;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.zy.bms.common.ServerResponse;
import com.zy.bms.entity.Item;
import com.zy.bms.pojo.io.ItemIO;
import com.zy.bms.service.IItemService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 项目表 前端控制器
 *
 * @author yangxiaokun
 * @since 2021-06-03
 */
@RestController
@RequestMapping("/bms/api/operate/item")
public class ItemController {
    @Resource
    private IItemService itemService;

    /**
     * 查询所有项目
     */
    @GetMapping("listAll.do")
    public ServerResponse listAll() {
        return ServerResponse.success(itemService.list());
    }

    /**
     * 分页查询所有项目
     */
    @GetMapping("listPage.do")
    public ServerResponse listPage(ItemIO io) {
        return ServerResponse.success(itemService.listPage(io));
    }

    /**
     * 添加项目
     */
    @PostMapping("save.do")
    public ServerResponse save(Item item) {
        itemService.save(item);
        return ServerResponse.success();
    }

    /**
     * 禁用项目
     */
    @GetMapping("forbidden.do")
    public ServerResponse forbidden(String id) {
        itemService.update(new UpdateWrapper<Item>().set("status", 0).eq("id", id));
        return ServerResponse.success();
    }

    /**
     * 启用项目
     */
    @GetMapping("permit.do")
    public ServerResponse permit(String id) {
        itemService.update(new UpdateWrapper<Item>().set("status", 1).eq("id", id));
        return ServerResponse.success();
    }

    /**
     * 更新项目信息
     */
    @PostMapping("update.do")
    public ServerResponse update(Item item) {
        itemService.updateById(item);
        return ServerResponse.success();
    }
}
