package com.zy.bms.handler;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zy.bms.common.Constant;
import com.zy.bms.entity.lp.LpInfoRecord;
import com.zy.bms.entity.lp.LpInfoState;
import com.zy.bms.pojo.dto.MqttDTO;
import com.zy.bms.pojo.dto.WakeAndThreshLpDTO;
import com.zy.bms.service.IPostMqttMsgService;
import com.zy.bms.service.lp.ILpInfoRecordService;
import com.zy.bms.service.lp.ILpInfoStateService;
import com.zy.bms.utils.BeanUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * 路牌 设备消息处理
 *
 * @author yang xiao kun
 * create on 2021/7/26
 */
@Slf4j
@Component
public class LpHandlers {

    @Resource
    private ILpInfoStateService lpInfoStateService;
    @Resource
    private ILpInfoRecordService lpInfoRecordService;
    @Resource
    private IPostMqttMsgService postMqttMsgService;

    /**
     * 基本信息上传
     */
    public void deviceInfoHandler(String openNum, MqttDTO mqttDTO) {
        //本地数据库信息
        LpInfoState local = lpInfoStateService.getByOpenNum(openNum);
        //接收远程设备信息
        LpInfoRecord record = TransformEntity.tsf2LpInfoRecord(openNum, mqttDTO);
        //存储历史记录
        lpInfoRecordService.save(record);
        //转换状态数据
        LpInfoState remote = BeanUtil.cast(record, LpInfoState.class);
        remote.setUpdateTime(record.getUploadTime());
        //若数据库中不存在设备信息直接插入
        if (local == null) {
            lpInfoStateService.save(remote);
            return;
        }
        setWakeAndThreshLp(openNum, local, remote);
        //更新数据库设备状态信息
        updateLpInfoStateService(openNum, remote);
    }

    /**
     * 定位信息上传
     */
    public void deviceLocationHandler(String openNum, MqttDTO mqttDTO) {
        LpInfoState device = TransformEntity.tsf2LpInfoStateLocation(openNum, mqttDTO);
        //收到定位信息,修改状态为0
        device.setUpdateLocationFlag(0);
        // 更新数据库设备状态信息
        updateLpInfoStateService(openNum, device);
    }

    /**
     * 设置 唤醒时间和阈值
     *
     * @param openNum 设备码
     * @param local   本地设置参数
     * @param remote  远程设置参数
     */
    private void setWakeAndThreshLp(String openNum, LpInfoState local, LpInfoState remote) {
        WakeAndThreshLpDTO dto = new WakeAndThreshLpDTO();
        dto.setOpenNum(openNum);
        //如果远程设备的(唤醒时间,阈值)与数据库的数据不一致,则发送消息更新设备的设置数据与数据库保持一致
        if (!local.getWakeInt().equals(remote.getWakeInt()) || !local.getThresh().equals(remote.getThresh())) {
            dto.setWakeInt(local.getWakeInt());
            dto.setThresh(local.getThresh());
            //以数据库为主,不需要更新这两个字段,故设置为null
            remote.setWakeInt(null);
            remote.setThresh(null);
        }
        //是否需要定位
        dto.setGetLocation(local.getUpdateLocationFlag() == 1 ? Constant.STATUS.TRUE : Constant.STATUS.FALSE);
        //是否需要更新数据
        dto.setSetf((dto.getWakeInt() != null || dto.getThresh() != null) ? Constant.STATUS.TRUE : Constant.STATUS.FALSE);
        postMqttMsgService.setWakeAndThreshLp(dto);
    }

    /**
     * 更新状态信息
     */
    private void updateLpInfoStateService(String openNum, LpInfoState lpInfoState) {
        //不更新设备码字段
        lpInfoState.setOpenNum(null);
        lpInfoStateService.update(lpInfoState, new QueryWrapper<LpInfoState>().eq("open_num", openNum));
    }
}
