package com.zy.bms.handler;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zy.bms.common.Constant;
import com.zy.bms.entity.*;
import com.zy.bms.pojo.dto.MqttDTO;
import com.zy.bms.service.*;
import com.zy.bms.utils.MD5Util;
import com.zy.bms.utils.RabbitMQApi;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * MQTT 消息返回处理类
 *
 * @author yang xiao kun
 * create on 2021/1/19
 */
@Slf4j
@Component
public class MqttCallbackHandler {

    @Resource
    private WebSocketHandler webSocketHandler;
    @Resource
    private IPostMqttMsgService postMqttMsgService;
    @Resource
    private ILogsService logsService;
    @Resource
    private IDeviceBaseService deviceBaseService;
    @Resource
    private UbiHandlers ubiHandlers;
    @Resource
    private LpHandlers lpHandlers;

    /**
     * 处理消息
     *
     * @param topic   主题
     * @param payload 消息内容
     */
    public void handle(String topic, String payload) {
        //设备码
        String openNum = Constant.splitOpenNum(topic);
        //解析数据
        MqttDTO mqttDTO = MqttDTO.parse(payload);
        // 1. 存储日志 --- 接收
        logsService.saveReceive(topic, payload);
        // 2. 根据报文标识代码 M 处理消息
        switch (mqttDTO.getM()) {
            case Constant.M.REGISTER: {//设备端注册报文
                registerHandler(mqttDTO);
                break;
            }
            case Constant.M.UBI_HEARTBEAT: {// 心跳包
                ubiHandlers.heartbeatHandler(openNum, mqttDTO);
                break;
            }
            case Constant.M.UBI_SET_INFO: {// 获取设备设置信息
                ubiHandlers.deviceSetHandler(openNum, mqttDTO);
                break;
            }
            case Constant.M.LP_HEARTBEAT: {// 获取设备设置信息
                lpHandlers.deviceInfoHandler(openNum, mqttDTO);
                break;
            }
            case Constant.M.LP_HEARTBEAT_LOCATION: {// 路牌-设备位置信息
                lpHandlers.deviceLocationHandler(openNum, mqttDTO);
                break;
            }
        }
        // 3. 转发消息至网页
        webSocketHandler.massMessage(openNum, payload);
    }

    /**
     * 注册设备
     */
    private void registerHandler(MqttDTO mqttDTO) {
        String openNum = mqttDTO.getString("regnum");
        // 查询数据库中是否有此设备
        DeviceBase device = deviceBaseService.getOne(new QueryWrapper<DeviceBase>().eq("open_num", openNum));
        // 没有该设备,保存至数据库
        if (device == null) {
            device = new DeviceBase();
            device.setOpenNum(openNum);
            device.setGroupId(mqttDTO.getString("group"));
            device.setType(mqttDTO.getString("type"));
            device.setUsername("IMEI" + openNum);
            device.setPassword(MD5Util.encode(openNum));
            device.setSn("SN" + openNum);
            deviceBaseService.save(device);
        }
        // mqtt服务器注册用户
        RabbitMQApi.register(device.getUsername(), device.getPassword());
        //路牌设备需要注册_lp结尾
        if (device.getType().equals(Constant.DEVICE_TYPE.LP)) {
            RabbitMQApi.register(device.getUsername() + "_lp", "123456");
        }
        // 返回处理结果
        postMqttMsgService.handleRegister(device);
    }
}
