package com.zy.bms.handler;

import com.zy.bms.common.Constant;
import com.zy.bms.entity.lp.LpInfoRecord;
import com.zy.bms.entity.lp.LpInfoState;
import com.zy.bms.entity.ubi.UbiInfoRecord;
import com.zy.bms.entity.ubi.UbiNtrip;
import com.zy.bms.entity.ubi.UbiTcp;
import com.zy.bms.pojo.dto.MqttDTO;
import com.zy.bms.utils.CoordTransformUtil;
import com.zy.bms.utils.GaoDeApiUtil;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.Map;

/**
 * 实体类转换
 *
 * @author yang xiao kun
 * create on 2021/7/6
 */
public class TransformEntity {

    /**
     * 普适性 - 心跳包记录
     */
    public static UbiInfoRecord tsf2UbiInfoRecord(String openNum, MqttDTO dto) {
        UbiInfoRecord result = new UbiInfoRecord();
        result.setOpenNum(openNum);
        result.setFreq(dto.getInt("freq"));
        result.setPowerVolt(dto.getDouble("powervolt"));
        result.setSatNum(dto.getInt("satnum"));
        result.setSignal4g(dto.getString("signal4g"));
        result.setLat(dto.getDouble("lat"));
        result.setLon(dto.getDouble("lon"));
        result.setVersion(dto.getString("version"));
        result.setUploadTime(dto.getDate("timee"));
        //转换后的坐标
        double[] gcj = CoordTransformUtil.wgs84toGcj02(result.getLon(), result.getLat());
        result.setLonGcj(gcj[0]);
        result.setLatGcj(gcj[1]);
        return result;
    }

    /**
     * 普适性 - 数据链路设置信息
     */
    public static UbiNtrip tsf2UbiNtrip(Map<String, String> map) {
        UbiNtrip result = new UbiNtrip();
        result.setOnOff(map.get("en") != null && map.get("en").equals(Constant.STATUS.ON) ? 1 : 0);
        result.setHost(map.get("host"));
        result.setPort(map.get("port"));
        result.setMountPoint(map.get("mountpoint"));
        result.setUser(map.get("user"));
        result.setPassword(map.get("password"));
        result.setStatus(map.get("linkF") != null && map.get("linkF").equals(Constant.STATUS.TRUE) ? 1 : 0);
        return result;
    }

    /**
     * 普适性 - TCP链路设置
     */
    public static UbiTcp tsf2UbiTcp(Map<String, String> map) {
        UbiTcp result = new UbiTcp();
        result.setOnOff(map.get("en") != null && map.get("en").equals(Constant.STATUS.ON) ? 1 : 0);
        result.setHost(map.get("host"));
        result.setPort(map.get("port"));
        result.setType(map.get("type"));
        result.setStatus(map.get("linkF") != null && map.get("linkF").equals(Constant.STATUS.TRUE) ? 1 : 0);
        return result;
    }

    /**
     * 路牌 - 状态信息
     */
    public static LpInfoRecord tsf2LpInfoRecord(String openNum, MqttDTO dto) {
        LpInfoRecord result = new LpInfoRecord();
        result.setOpenNum(openNum);
        result.setWakeInt(dto.getDouble("sleept") == null ? null : BigDecimal.valueOf(dto.getDouble("sleept")).setScale(2, BigDecimal.ROUND_HALF_UP));
        result.setThresh(dto.getInt("thresh"));
        result.setDataType(dto.getString("datatype"));
        result.setBattery(dto.getString("batterynum"));
        result.setS4g(dto.getString("s4g"));
        result.setX(dto.getString("x"));
        result.setY(dto.getString("y"));
        result.setZ(dto.getString("z"));
        result.setAnglex(dto.getString("anglex"));
        result.setAngley(dto.getString("angley"));
        result.setAnglez(dto.getString("anglez"));
        result.setTemp(dto.getString("temp"));
        result.setUploadTime(LocalDateTime.now());
        return result;
    }

    /**
     * 路牌 - 状态信息
     */
    public static LpInfoState tsf2LpInfoStateLocation(String openNum, MqttDTO dto) {
        LpInfoState result = new LpInfoState();
        result.setOpenNum(openNum);
        Double lon = dto.getDouble("lon");
        Double lat = dto.getDouble("lat");
        result.setMode(dto.getInt("mode"));
        result.setLon(lon);
        result.setLat(lat);
        //转换后的坐标
        double[] gcj = CoordTransformUtil.wgs84toGcj02(lon, lat);
        result.setLonGcj(gcj[0]);
        result.setLatGcj(gcj[1]);
        // 逆地理位置解析
        result.setSite(GaoDeApiUtil.regeo(lon.toString(), lat.toString()));
        result.setUpdateTime(LocalDateTime.now());
        return result;
    }
}
