package com.zy.bms.handler;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zy.bms.common.exception.ApiRuntimeException;
import com.zy.bms.entity.ubi.UbiInfoRecord;
import com.zy.bms.entity.ubi.UbiInfoState;
import com.zy.bms.entity.ubi.UbiNtrip;
import com.zy.bms.entity.ubi.UbiTcp;
import com.zy.bms.pojo.dto.MqttDTO;
import com.zy.bms.service.ubi.IUbiInfoRecordService;
import com.zy.bms.service.ubi.IUbiInfoStateService;
import com.zy.bms.service.ubi.IUbiNtripService;
import com.zy.bms.service.ubi.IUbiTcpService;
import com.zy.bms.utils.BeanUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.Map;

/**
 * 普适性 设备消息处理
 *
 * @author yang xiao kun
 * create on 2021/7/26
 */
@Slf4j
@Component
public class UbiHandlers {

    @Resource
    private IUbiInfoRecordService heartbeatRecordService;
    @Resource
    private IUbiInfoStateService deviceDynamicService;
    @Resource
    private IUbiNtripService ntripSetService;
    @Resource
    private IUbiTcpService tcpSetService;


    /**
     * 心跳协议
     */
    public void heartbeatHandler(String openNum, MqttDTO mqttDTO) {
        UbiInfoRecord entity = TransformEntity.tsf2UbiInfoRecord(openNum, mqttDTO);
        //存储记录
        heartbeatRecordService.save(entity);
        //更新最新的记录
        UbiInfoState ubiInfoState = BeanUtil.cast(entity, UbiInfoState.class);
        //设置更新时间
        ubiInfoState.setUpdateTime(LocalDateTime.now());
        //设置在线状态
        ubiInfoState.setStatus(1);
        deviceDynamicService.saveOrUpdate(ubiInfoState,
                new QueryWrapper<UbiInfoState>().eq("open_num", ubiInfoState.getOpenNum()));
    }

    /**
     * 普适性-设备设置信息
     */
    @SuppressWarnings("unchecked")
    public void deviceSetHandler(String openNum, MqttDTO mqttDTO) {
        // ntrip数据链路设置
        UbiNtrip client = TransformEntity.tsf2UbiNtrip((Map<String, String>) mqttDTO.getObject("ntripclient"));
        UbiNtrip server = TransformEntity.tsf2UbiNtrip((Map<String, String>) mqttDTO.getObject("ntripserver"));
        ntripSetService.saveOrUpdateNtripSet(client, openNum, IUbiNtripService.CLIENT);
        ntripSetService.saveOrUpdateNtripSet(server, openNum, IUbiNtripService.SERVER);
        // tcp数据链路设置
        UbiTcp link1 = TransformEntity.tsf2UbiTcp((Map<String, String>) mqttDTO.getObject("tcplink1"));
        UbiTcp link2 = TransformEntity.tsf2UbiTcp((Map<String, String>) mqttDTO.getObject("tcplink2"));
        UbiTcp link3 = TransformEntity.tsf2UbiTcp((Map<String, String>) mqttDTO.getObject("tcplink3"));
        tcpSetService.saveOrUpdateTcpSet(link1, openNum, IUbiTcpService.LINK_1);
        tcpSetService.saveOrUpdateTcpSet(link2, openNum, IUbiTcpService.LINK_2);
        tcpSetService.saveOrUpdateTcpSet(link3, openNum, IUbiTcpService.LINK_3);
    }
}
