package com.zy.bms.pojo.dto;

import com.alibaba.fastjson.JSON;
import com.zy.bms.utils.DateTimeUtil;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * MQTT 消息模板类
 *
 * @author yang xiao kun
 * create on 2021/1/21
 */
@Data
@NoArgsConstructor
public class MqttDTO {
    /**
     * M 指令
     */
    private String m;
    /**
     * 数据项
     */
    private Map<String, Object> data;

    /**
     * 通用构造器
     *
     * @param m 报文协议 code值
     */
    public MqttDTO(String m) {
        this.m = m;
        this.data = new HashMap<>();
    }

    /**
     * 由 JSON 字符串 转 MqttMsgDto 对象
     */
    public static MqttDTO parse(String jsonStr) {
        return JSON.parseObject(jsonStr, MqttDTO.class);
    }

    /**
     * 往data中添加数据 链式
     *
     * @param key   键
     * @param value 值
     */
    public MqttDTO put(String key, Object value) {
        data.put(key, value);
        return this;
    }

    /**
     * 获取json 对象
     */
    public String json() {
        return JSON.toJSONString(this);
    }

    /**
     * 获取 Object 数据
     */
    public Object getObject(String key) {
        return data.get(key);
    }

    /**
     * 获取String 数据
     */
    public String getString(String key) {
        return data.containsKey(key) ? data.get(key).toString() : null;
    }

    /**
     * 获取 Integer 数据
     */
    public Integer getInt(String key) {
        return isNull(key) ? null : Integer.parseInt(data.get(key).toString());
    }

    /**
     * 获取 Double 数据
     */
    public Double getDouble(String key) {
        return isNull(key) ? null : Double.parseDouble(data.get(key).toString());
    }

    /**
     * 获取 日期数据 数据
     */
    public LocalDateTime getDate(String key) {
        if (isNull(key)) return null;
        try {
            return DateTimeUtil.strToTime(data.get(key).toString(), DateTimeUtil.Pattern_YMDHMS);
        } catch (Exception e) {
            return DateTimeUtil.strToTime(data.get(key).toString(), DateTimeUtil.Pattern_YMDHMS2);
        }
    }

    /**
     * 判断是否为空
     *
     * @param key key
     */
    private boolean isNull(String key) {
        return (!data.containsKey(key) || data.get(key).toString().equals(""));
    }
}
