package com.zy.bms.utils;

import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import java.security.Key;
import java.security.SecureRandom;
import java.util.Base64;

/**
 * AES对称加密工具类
 *
 * @author yangxiaokun
 */
public class AesUtil {

    private static final String KEY_ALGORITHM = "AES";
    private static final String CIPHER_ALGORITHM = "AES/ECB/PKCS5Padding";
    //进行了Base64编码的秘钥(由keyGenerate()方法生成的)
    private static final String KEY_NUM = "6RAwrG9BcU1D1bObGGskqw==";

    /**
     * AES对称-加密操作
     *
     * @param data 需要进行加密的原文
     * @return 数据密文，加密后的数据，进行了Base64的编码
     */
    public static String encrypt(String data) {
        try {
            // 转换密钥
            Key key = new SecretKeySpec(Base64.getDecoder().decode(KEY_NUM), KEY_ALGORITHM);
            Cipher cipher = Cipher.getInstance(CIPHER_ALGORITHM);
            // 加密
            cipher.init(Cipher.ENCRYPT_MODE, key);
            byte[] result = cipher.doFinal(data.getBytes());
            return Base64.getEncoder().encodeToString(result);
        } catch (Exception e) {
            return "AES";
        }
    }

    /**
     * @param data 需要解密的数据（数据必须是通过AES进行加密后，对加密数据Base64编码的数据）
     * @return String 返回解密后的原文
     */
    public static String decrypt(String data) {
        try {
            // 转换密钥
            Key key = new SecretKeySpec(Base64.getDecoder().decode(KEY_NUM), KEY_ALGORITHM);
            Cipher cipher = Cipher.getInstance(CIPHER_ALGORITHM);
            // 解密
            cipher.init(Cipher.DECRYPT_MODE, key);
            byte[] result = cipher.doFinal(Base64.getDecoder().decode(data));
            return new String(result);
        } catch (Exception e) {
            return null;
        }
    }

    /**
     * 生成AES的秘钥，秘钥进行了Base64编码的字符串
     *
     * @return 对生成的秘钥进行了Base64编码的字符串
     */
    private static String keyGenerate() throws Exception {
        // 生成密钥
        KeyGenerator keyGenerator = KeyGenerator.getInstance(KEY_ALGORITHM);
        keyGenerator.init(new SecureRandom());
        SecretKey secretKey = keyGenerator.generateKey();
        byte[] keyBytes = secretKey.getEncoded();
        return Base64.getEncoder().encodeToString(keyBytes);
    }
}