package com.zy.bms.utils;

import org.springframework.http.*;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.net.URI;
import java.util.Map;

/**
 * Http 工具类
 *
 * @author chenyi
 * date create on 2019/4/21
 */
public class HttpUtil {

    private static final RestTemplate restTemplate = new RestTemplate();

    /**
     * 发送 PUT 请求
     *
     * @param url 请求地址
     */
    public static String putForJSONEntity(String url, HttpHeaders header, String json) {
        header.setContentType(MediaType.APPLICATION_JSON);
        HttpEntity<String> httpEntity = new HttpEntity<>(json, header);
        return restTemplate.exchange(URI.create(url), HttpMethod.PUT, httpEntity, String.class).getBody();
    }

    /**
     * 发送 Get 请求
     *
     * @param url 请求地址
     */
    public static String getForEntity(String url, HttpHeaders header, Object... uriVariables) {
        HttpEntity<String> httpEntity = new HttpEntity<>(header);
        ResponseEntity<String> result = restTemplate.exchange(url, HttpMethod.GET, httpEntity, String.class, uriVariables);
        return result.getBody();
    }

    /**
     * 发送 Get 请求
     *
     * @param url          请求地址
     * @param uriVariables 请求参数
     */
    public static String getForEntity(String url, Object... uriVariables) {
        ResponseEntity<String> result = restTemplate.getForEntity(url, String.class, uriVariables);
        return result.getBody();
    }

    /**
     * 发送 POST 请求
     * JSON 格式请求信息
     *
     * @param url    地址
     * @param params 参数
     */
    public static String post(String url, Map<String, String> header, MultiValueMap<String, String> params) {
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
        //设置请求头信息
        if (header != null && !header.isEmpty()) {
            for (Map.Entry<String, String> entry : header.entrySet()) {
                headers.add(entry.getKey(), entry.getValue());
            }
        }
        HttpEntity<MultiValueMap<String, String>> request = new HttpEntity<>(params, headers);
        return restTemplate.postForEntity(url, request, String.class).getBody();
    }
}
